# frozen_string_literal: true

require 'test_helper'
# rake test TEST=test/business_central/object/general_ledger_entry_test.rb

class BusinessCentral::Object::GeneralLedgerEntryTest < Minitest::Test
  def setup
    @company_id = '123456'
    @client = BusinessCentral::Client.new
    @general_ledger_entry = @client.general_ledger_entry(company_id: @company_id)
  end

  def test_find_all
    stub_request(:get, /generalLedgerEntries/)
      .to_return(
        status: 200,
        body: {
          'value': [
            {
              id: 1,
              number: '1009'
            }
          ]
        }.to_json
      )

    response = @general_ledger_entry.find_all
    assert_equal response.first[:number], '1009'
  end

  def test_find_by_id
    test_id = '09876'
    stub_request(:get, /generalLedgerEntries\(#{test_id}\)/)
      .to_return(
        status: 200,
        body: {
          id: test_id,
          number: '1010'
        }.to_json
      )

    response = @general_ledger_entry.find_by_id(test_id)
    assert_equal response[:number], '1010'
  end

  def test_where
    test_filter = "number eq '1020'"
    stub_request(:get, /generalLedgerEntries\?\$filter=#{test_filter}/)
      .to_return(
        status: 200,
        body: {
          'value': [
            {
              id: '345',
              number: '1011'
            }
          ]
        }.to_json
      )

    response = @general_ledger_entry.where(test_filter)
    assert_equal response.first[:number], '1011'
  end

  def test_create
    assert_raises BusinessCentral::NoSupportedMethod do
      @general_ledger_entry.create({})
    end
  end

  def test_update
    assert_raises BusinessCentral::NoSupportedMethod do
      @general_ledger_entry.update('123', {})
    end
  end

  def test_delete
    assert_raises BusinessCentral::NoSupportedMethod do
      @general_ledger_entry.destroy('123')
    end
  end
end
